import request from '@/utils/request'

// 查询生产记录列表
export function listPrdRecord(query) {
  return request({
    url: '/production/prdRecord/list',
    method: 'get',
    params: query
  })
}

// 查询生产记录详细
export function getPrdRecord(id) {
  return request({
    url: '/production/prdRecord/' + id,
    method: 'get'
  })
}

// 新增生产记录
export function addPrdRecord(data) {
  return request({
    url: '/production/prdRecord',
    method: 'post',
    data: data
  })
}

// 修改生产记录
export function updatePrdRecord(data) {
  return request({
    url: '/production/prdRecord',
    method: 'put',
    data: data
  })
}

// 删除生产记录
export function delPrdRecord(id) {
  return request({
    url: '/production/prdRecord/' + id,
    method: 'delete'
  })
}

// 导出生产记录
export function exportPrdRecord(query) {
  return request({
    url: '/production/prdRecord/export',
    method: 'get',
    params: query
  })
}

// 导出生产记录
export function exportPrdRecordMonth(query) {
  return request({
    url: '/production/prdRecord/exportMonth',
    method: 'get',
    params: query
  })
}

